"""bookmark domain — model, schemas, validators, and repository."""

from repo_core.domains.bookmark.model import Bookmark, BookmarkTargetType
from repo_core.domains.bookmark.schema import (
    CreateBookmarkRequest,
    BookmarkResponse,
    BookmarkCheckResponse,
)
from repo_core.domains.bookmark.validator import BookmarkTargetIdValidator
from repo_core.domains.bookmark.repository import BookmarkRepository

__all__ = [
    "Bookmark",
    "BookmarkTargetType",
    "CreateBookmarkRequest",
    "BookmarkResponse",
    "BookmarkCheckResponse",
    "BookmarkTargetIdValidator",
    "BookmarkRepository",
]
